@@ -1,5 +1,3 @@
-# $Id: Constants.pm,v 1.7 2001/08/09 04:28:57 btrott Exp $
-
 package Crypt::OpenPGP::Constants;
 use strict;
 
@@ -63,10 +61,6 @@ __END__
 
 Crypt::OpenPGP::Constants - Exportable constants
 
-=head1 SYNOPSIS
-
-    use Crypt::OpenPGP::Constants qw( :tag CONSTANT1 );
-
 =head1 DESCRIPTION
 
 I<Crypt::OpenPGP::Constants> provides a list of common and useful
