@@ -1,5 +1,3 @@
-# $Id: Marker.pm,v 1.2 2001/07/29 04:26:05 btrott Exp $
-
 package Crypt::OpenPGP::Marker;
 use strict;
 
@@ -22,11 +20,6 @@ __END__
 
 Crypt::OpenPGP::Marker - PGP Marker packet
 
-=head1 SYNOPSIS
-
-    use Crypt::OpenPGP::Marker;
-    my $marker = Crypt::OpenPGP::Marker->parse($buffer);
-
 =head1 DESCRIPTION
 
 I<Crypt::OpenPGP::Marker> is a PGP Marker packet. These packets are
