@@ -1,5 +1,3 @@
-# $Id: OnePassSig.pm,v 1.4 2001/07/29 17:42:59 btrott Exp $
-
 package Crypt::OpenPGP::OnePassSig;
 use strict;
 
@@ -25,12 +23,6 @@ __END__
 
 Crypt::OpenPGP::OnePassSig - One-Pass Signature packet
 
-=head1 SYNOPSIS
-
-    use Crypt::OpenPGP::OnePassSig;
-
-    my $onepass = Crypt::OpenPGP::OnePassSig->parse($buffer);
-
 =head1 DESCRIPTION
 
 I<Crypt::OpenPGP::OnePassSig> implements a PGP One-Pass Signature
