@@ -1,5 +1,3 @@
-# $Id: Trust.pm,v 1.3 2001/07/29 06:34:29 btrott Exp $
-
 package Crypt::OpenPGP::Trust;
 use strict;
 
@@ -23,11 +21,6 @@ __END__
 
 Crypt::OpenPGP::Trust - PGP Trust packet
 
-=head1 SYNOPSIS
-
-    use Crypt::OpenPGP::Trust;
-    my $trust = Crypt::OpenPGP::Trust->parse($buffer);
-
 =head1 DESCRIPTION
 
 I<Crypt::OpenPGP::Trust> is a PGP Trust packet. From the OpenPGP
