@@ -1,5 +1,3 @@
-# $Id: Util.pm,v 1.9 2002/07/12 23:52:33 btrott Exp $
-
 package Crypt::OpenPGP::Util;
 use strict;
 
@@ -85,10 +83,6 @@ __END__
 
 Crypt::OpenPGP::Util - Miscellaneous utility functions
 
-=head1 SYNOPSIS
-
-    use Crypt::OpenPGP::Util qw( func1 func2 ... );
-
 =head1 DESCRIPTION
 
 I<Crypt::OpenPGP::Util> contains a set of exportable utility functions
